#
# spec file for package python
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global sname cotyledon
Name:           python-%{sname}
Version:        1.7.1
Release:        3.52
Summary:        A framework for defining long-running services
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/sileht/cotyledon
Source:         https://files.pythonhosted.org/packages/source/c/%{sname}/%{sname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: https://github.com/sileht/cotyledon/pull/19
Patch1:         fix_arm.patch
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module oslo.config >= 3.14.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setproctitle}
BuildRequires:  %{python_module setuptools >= 30.3.0}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
Requires:       python-setproctitle
BuildRequires:  fdupes
BuildArch:      noarch

%description
Cotyledon provides a framework for defining long-running services.

%python_subpackages

%package -n python-%{sname}-doc
Summary:        Documentation for cotyledon, a framework for long-running services
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description -n python-%{sname}-doc
Cotyledon provides a framework for defining long-running services.

This package contains documentation files for %{name}.

%prep
%setup -q -n %{sname}-%{version}
%patch1 -p1
rm tox.ini

%build
%python_build
python3 setup.py build_sphinx
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONDONTWRITEBYTECODE=1
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_version} -v cotyledon/tests

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/%{sname}
%{python_sitelib}/*.egg-info

%files -n python-%{sname}-doc
%license LICENSE
%doc README.rst
%doc doc/build/html

%changelog
* Wed Nov 28 2018 guillaume.gardet@opensuse.org
- Add patch to fix random test failure on ARM:
  * fix_arm.patch
* Fri Oct 12 2018 tchvatal@suse.com
- Update dependencies based on upstream setup.py/requirements
- Update to 1.7.1:
  * No obvious changelog except of git log
- Use py3 to generate documentation
- Run tests on all python variants
* Sat Jul 14 2018 jengelh@inai.de
- rpmlint: avoid repeating name in summary
* Mon Jul  9 2018 dmueller@suse.com
- switch to single-spec
* Fri Aug 25 2017 tbechtold@suse.com
- update to 1.6.8:
  * Fix terminate when workers fail to start
  * We don't care about child status when we exit
  * setup.cfg: Remove useless section
  * Fix a typo in service_manager docstring
  * Check user input
  * Increase 'fork too fast' sleep time
  * Fix sigchld for window
  * Use sigchld instead of polling children
  * Update sphinx
  * reduce cpu usage
  * Reword README
  * Fix forking too fast code
  * doc: Add note about futurist
  * Switch doc to rtd theme
  * doc enhancement
  * doc: hooks and window note
  * always run signal handling in main thread
  * window: Don't fail is the app use oslo.config
  * tests: fix py35
  * tests: add a basic workflow for window
  * tests/doc/window: oslo.config limitation
  * tests: Don't use stdout
  * window: clarify SIGTERM/SIGALRM/SIGBREAK state
  * tests: window failfast
  * tests: Don't use signal 0
  * window: Fix signals for children
  * tests: skip sighup tests
  * tests: fixing logging on window
  * fixing import order
  * Make option mutable
  * Add tea-ci.org supports
  * doc: Add some non-posix note
  * Close useless child pipe()
  * simplify the dead worker detection/restarting
  * doc: Add some non-posix note
  * add some py3 note
  * Bump the major version for the non-posix support
  * workaround killpg on non-posix platform
  * Simplify the running_services structure
  * Fix signal handling for windows
  * Make setproctitle optional for windows
  * Ignore setsid AttributeError on windows
  * Remove usage of os.waitpid
  * Use multiprocessing.Process instead of fork
* Wed Oct 12 2016 dmueller@suse.com
- update to 1.5.0:
  * Rework the oslo_config_glue
  * Implement sigalarm for servicemanager
  * Allow to register multiple hooks
  * Add on_new_worker hooks
  * Improve tests output and run doc8
  * Tests: fix tests cleanup
  * Remove unused file
  * Improve docs
  * Split code base
  * Allow to register terminate/reload hooks
  * Share signals implementation
  * Allows to reconfigure a service
  * Revert "limit select.select() EINTR exception"
  * Don't wait for reload if terminate/reload already run
  * limit select.select() EINTR exception
  * Handle SIGALRM like other signals
  * set proc title for master process
  * doc: add some clarification
  * Rework signal handlers
  * Fixup code blocks
  * fix sporadic test failure
  * Set default python interpreter version to 3.5
* Fri Jul 15 2016 aplanas@suse.com
- Add initial version (1.2.6) of cotyledon package
